@@ -18,6 +18,7 @@ from wolframclient.serializers.wxfencoder.utils import write_varint
 from wolframclient.tests.configure import skip_for_jython
 from wolframclient.utils import six
 from wolframclient.utils.api import numpy
+from wolframclient.utils.datastructures import immutabledict
 from wolframclient.utils.tests import TestCase as BaseTestCase
 
 
@@ -199,6 +200,13 @@ class TestCase(BaseTestCase):
         res = binary_deserialize(wxf, consumer=WXFConsumer())
         self.assertEqual(expr, res)
 
+    def test_nested_associations(self):
+        expr = immutabledict((("a", 2), ("a", 3)))
+        expr = immutabledict(((expr, expr), (2, 3)))
+        wxf = export(expr, target_format="wxf", compress=True)
+        res = binary_deserialize(wxf, consumer=WXFConsumer())
+        self.assertEqual(expr, res)
+
     # Custom consumers
     class BadGreedyConsumer(WXFConsumer):
         def consume_function(self, current_token, tokens, **kwargs):
